==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTQUALIFICATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for EQUIPMENTQUALIFICATIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="EQUIPMENTQUALIFICATIONID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}QUALIFICATIONID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}STARTDATE"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTQUALIFICATIONID_Type", propOrder = {
    "equipmentid",
    "qualificationid",
    "startdate"
})
public class EQUIPMENTQUALIFICATIONID_Type {

    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "QUALIFICATIONID", required = true)
    protected QUALIFICATIONID_Type qualificationid;
    @XmlElement(name = "STARTDATE", required = true)
    protected DATETIME startdate;

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the qualificationid property.
     * 
     * @return
     *     possible object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public QUALIFICATIONID_Type getQUALIFICATIONID() {
        return qualificationid;
    }

    /**
     * Sets the value of the qualificationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public void setQUALIFICATIONID(QUALIFICATIONID_Type value) {
        this.qualificationid = value;
    }

    /**
     * Gets the value of the startdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Sets the value of the startdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_fields/EQUIPMENTQUALIFICATIONID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Java class for EQUIPMENTQUALIFICATIONID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="EQUIPMENTQUALIFICATIONID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}EQUIPMENTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}QUALIFICATIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STARTDATE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EQUIPMENTQUALIFICATIONID_Type", propOrder = {
    "equipmentid",
    "qualificationid",
    "startdate"
})
public class EQUIPMENTQUALIFICATIONID_Type {

    @XmlElement(name = "EQUIPMENTID", required = true)
    protected EQUIPMENTID_Type equipmentid;
    @XmlElement(name = "QUALIFICATIONID", required = true)
    protected QUALIFICATIONID_Type qualificationid;
    @XmlElement(name = "STARTDATE", required = true)
    protected DATETIME startdate;

    /**
     * Gets the value of the equipmentid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getEQUIPMENTID() {
        return equipmentid;
    }

    /**
     * Sets the value of the equipmentid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setEQUIPMENTID(EQUIPMENTID_Type value) {
        this.equipmentid = value;
    }

    /**
     * Gets the value of the qualificationid property.
     * 
     * @return
     *     possible object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public QUALIFICATIONID_Type getQUALIFICATIONID() {
        return qualificationid;
    }

    /**
     * Sets the value of the qualificationid property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUALIFICATIONID_Type }
     *     
     */
    public void setQUALIFICATIONID(QUALIFICATIONID_Type value) {
        this.qualificationid = value;
    }

    /**
     * Gets the value of the startdate property.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getSTARTDATE() {
        return startdate;
    }

    /**
     * Sets the value of the startdate property.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setSTARTDATE(DATETIME value) {
        this.startdate = value;
    }

}
